#!/usr/bin/python
"GNS mud items database interface"
import csv
import random
import sys


class GnsItem():
    "An item in GNS mud"
    def __init__(self, csvdict):
        self.attributes = dict()
        self.longflags = []
        self.shortflags = ""
        for key, value in csvdict.items():
            if value in ('0', ''):
                pass
            elif key == 'Name':
                self.name = value
                self.attributes[key] = value
            elif value == '1' and key != "Weight":
                if len(key) == 1:
                    self.shortflags += key
                else:
                    self.longflags.append(key)
            else:
                self.attributes[key] = value

    def has_flag(self, flag):
        "return True if this item has that flag"
        return flag in self.longflags or flag in self.shortflags

    def __str__(self):
        "print data in human-readable form to stdout"
        output = ""
        for key, value in self.attributes.items():
            output += "{}: {}\n".format(key, value)
        output += "Long Flags: " + ", ".join(self.longflags) + "\n"
        output += "Short Flags: " + self.shortflags
        return output


class GnsItems():
    "Data about Items in GNS mud"
    def __init__(self):
        self.items = set()
        with open('gns-items.csv') as datafile:
            self.headers = datafile.readline().split(',')
        with open('gns-items.csv') as datafile:
            for row in csv.DictReader(datafile):
                self.items.add(GnsItem(row))

    def print_random(self):
        "print data about a random item in the database"
        item = random.sample(self.items, 1)[0]
        print(item)

    def print_match(self, args):
        "print items whose name matches all args"
        matches = []
        for item in self.items:
            matching = True
            for arg in args:
                if arg not in item.name:
                    matching = False
            if matching:
                matches.append(str(item))

        print("\n\n".join(matches))


if __name__ == "__main__":
    ITEMS = GnsItems()
    # ITEMS.print_match("catfish")
    # ITEMS.print_random()
    # ITEMS.print_match("holy symbol")
    ITEMS.print_match(sys.argv[1:])

# ------------------------
# CopyLeft by dalker
# create date: 2018-09-02
# modif  date: 2018-09-02
# ------------------------
